/*
 * Copyright (c) 2017-2020. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.snooker.cache.assign;

import org.hedgecode.snooker.api.APIException;
import org.hedgecode.snooker.api.Event;
import org.hedgecode.snooker.api.Player;
import org.hedgecode.snooker.json.JsonEvent;

/**
 * Assigner for Entity fields of {@link Event}.
 *
 * @author Dmitry Samoshin aka gotty
 */
public class EventAssigner extends CacheIdAssigner<Event> {

    private static EventAssigner _instance;

    private EventAssigner() {
    }

    public static EventAssigner getInstance() {
        if (_instance == null)
            _instance = new EventAssigner();
        return _instance;
    }

    @Override
    public void assign(Event event) throws APIException {
        JsonEvent jsonEvent = (JsonEvent) event;
        if (event.mainEventId() != event.eventId() && event.mainEventId() > 0) {
            jsonEvent.setMainEvent(
                    cacheScore.getCachedEvent(
                            event.mainEventId()
                    )
            );
        }
        if (event.previousEditionId() > 0) {
            jsonEvent.setPreviousEdition(
                    cacheScore.getCachedEvent(
                            event.previousEditionId()
                    )
            );
        }
        if (event.defendingChampionId() > 0) {
            jsonEvent.setDefendingChampion(
                    cacheScore.getCachedPlayer(
                            event.defendingChampionId()
                    )
            );
        }
    }

}
