/*
 * Copyright (c) 2017-2020. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.snooker.compare;

import java.io.Serializable;
import java.util.Comparator;

import org.hedgecode.snooker.api.Event;

/**
 * Set of Comparators for {@link Event}.
 * 1. Sorting by Date {@link DateComparator};
 * 2. Sorting by WorldSnookerId {@link SnookerIdComparator}.
 *
 * @author Dmitry Samoshin aka gotty
 */
public enum EventComparators {

    DATE       ( new DateComparator() ),
    SNOOKER_ID ( new SnookerIdComparator() );

    private Comparator<Event> comparator;

    EventComparators(Comparator<Event> comparator) {
        this.comparator = comparator;
    }

    public Comparator<Event> comparator() {
        return comparator;
    }

    static class DateComparator implements Comparator<Event>, Serializable {

        @Override
        public int compare(Event event1, Event event2) {
            return event1.startDate().compareTo(event2.startDate());
        }

    }

    static class SnookerIdComparator implements Comparator<Event>, Serializable {

        @Override
        public int compare(Event event1, Event event2) {
            return event1.worldSnookerId() - event2.worldSnookerId();
        }

    }

}
