/*
 * Copyright (c) 2017-2020. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.snooker.request;

/**
 * Requester of a Match by Event, Round and Number.
 *
 * @author Dmitry Samoshin aka gotty
 */
public class MatchRequester extends AbstractRequester {

    private static final String MATCH_URL =
            API_SNOOKER_URL + "?e=[EventID]&r=[RoundID]&n=[MatchNumber]";

    private static final Requester _instance = new MatchRequester();

    private MatchRequester() {
    }

    public static Requester getInstance() {
        return _instance;
    }

    @Override
    protected String getRequestUrl(int id) throws RequestException {
        throw new RequestException(MATCH_URL, "Incorrect Match Params");
    }

    @Override
    protected String getRequestUrl(RequestParams params) throws RequestException {
        if (params == null
                || !isCorrectId(params.getEventId())
                || !isCorrectId(params.getRoundId())
                || !isCorrectId(params.getMatchNumber()))
            throw new RequestException(MATCH_URL, "Incorrect Match Params");

        return MATCH_URL.replace(
                "[EventID]", String.valueOf(params.getEventId())
        ).replace(
                "[RoundID]", String.valueOf(params.getRoundId())
        ).replace(
                "[MatchNumber]", String.valueOf(params.getMatchNumber())
        );
    }

}
