/*
 * Copyright (c) 2017-2020. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.snooker.request;

import org.hedgecode.snooker.api.Season;

/**
 * Requester of Events in a Season.
 *
 * @author Dmitry Samoshin aka gotty
 */
public class SeasonEventsRequester extends AbstractRequester {

    private static final String SEASON_EVENTS_URL = API_SNOOKER_URL + "?t=5&s=[Season]";

    private static final Requester _instance = new SeasonEventsRequester();

    private SeasonEventsRequester() {
    }

    public static Requester getInstance() {
        return _instance;
    }

    @Override
    protected String getRequestUrl(int id) throws RequestException {
        return SEASON_EVENTS_URL.replace(
                "[Season]", String.valueOf(Season.CURRENT_YEAR)
        );
    }

    @Override
    protected String getRequestUrl(RequestParams params) throws RequestException {
        if (params == null || params.getSeason() == null)
            throw new RequestException(SEASON_EVENTS_URL, "Incorrect Season");

        return SEASON_EVENTS_URL.replace(
                "[Season]", String.valueOf(params.getSeason().getYear())
        );
    }

}
