/*
 * Copyright (c) 2017-2020. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.snooker.request;

import org.hedgecode.snooker.api.PlayerCategory;
import org.hedgecode.snooker.api.Season;

/**
 * Requester of Players in a Season.
 *
 * @author Dmitry Samoshin aka gotty
 */
public class SeasonPlayersRequester extends AbstractRequester {

    private static final String SEASON_PLAYERS_URL =
            API_SNOOKER_URL + "?t=10&st=[Category]&s=[Season]";

    private static final Requester _instance = new SeasonPlayersRequester();

    private SeasonPlayersRequester() {
    }

    public static Requester getInstance() {
        return _instance;
    }

    @Override
    protected String getRequestUrl(int id) throws RequestException {
        return SEASON_PLAYERS_URL.replace(
                "[Category]", PlayerCategory.PRO.letter()
        ).replace(
                "[Season]", String.valueOf(Season.CURRENT_YEAR)
        );
    }

    @Override
    protected String getRequestUrl(RequestParams params) throws RequestException {
        if (params == null
                || params.getCategory() == null
                || params.getSeason() == null)
            throw new RequestException(SEASON_PLAYERS_URL, "Incorrect Players Params");

        return SEASON_PLAYERS_URL.replace(
                "[Category]", params.getCategory().letter()
        ).replace(
                "[Season]", String.valueOf(params.getSeason().getYear())
        );
    }

}
